@@ -1,6 +1,6 @@
 ##----------------------------------------------------------------------------
 ## URI::tel - ~/lib/URI/tel.pm
-## Version v0.801.0
+## Version v0.801.1
 ## Copyright(c) 2021 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2016/02/12
@@ -19,7 +19,7 @@ BEGIN
     our( $RESERVED, $MARK, $UNRESERVED, $PCT_ENCODED, $URIC, $ALPHA, $DIGIT, $ALPHANUM, $HEXDIG );
     our( $PARAM_UNRESERVED, $VISUAL_SEPARATOR, $PHONEDIGIT, $GLOBAL_NUMBER_DIGITS, $PARAMCHAR, $DOMAINLABEL, $TOPLABEL, $DOMAINNAME, $DESCRIPTOR, $PNAME, $PVALUE, $PARAMETER, $EXTENSION, $ISDN_SUBADDRESS, $CONTEXT, $PAR, $PHONEDIGIT_HEX, $GLOBAL_NUMBER, $LOCAL_NUMBER, $OTHER, $TEL_SUBSCRIBER, $TEL_URI, $VANITY, $VANITY_LOCAL );
     our( $COUNTRIES, $IDD_RE );
-    $VERSION     = 'v0.801.0';
+    $VERSION     = 'v0.801.1';
     use overload ('""'     => 'as_string',
                   '=='     => sub { _obj_eq(@_) },
                   '!='     => sub { !_obj_eq(@_) },
@@ -952,7 +952,7 @@ This returns the international code, if any. The international code is the inter
     tel:656-9254;ext=102;phone-context=+1-212
     tel:911;phone-context=+1
 
-If an international country code is provided, it will be used to get information such as country name and iso 3166 country codes and also it will be used in formatting the phone number by prefixing the subscriber number with the international country code provided. If, instead you want to just set a context, then use the B<context> method instead. For example with a subscriber number such as I<911>, you may want to give it some context by adding +1 such as :
+If an international country code is provided, it will be used to get information such as country name and iso 3166 country codes and also it will be used in formatting the phone number by prefixing the subscriber number with the international country code provided. If, instead you want to just set a context, then use the L</context> method instead. For example with a subscriber number such as I<911>, you may want to give it some context by adding +1 such as :
 
     my $tel = URI::tel->new( "911" );
     $tel->context( '+1' );
@@ -997,14 +997,18 @@ It returns the current value set.
 
     $tel->isub( 1420 );
 
+=head2 local_number
+
+Returns the local phone number. For example for a number such as C<+81-090-1234-5678>, this would return C<090-1234-5678>
+
 =head2 original
 
 Returns the original telephone number provided, before any possible changes were brought.
 
 =head2 private( [ NAME, [ VALUE ] ] )
 
-Given a I<NAME>, B<private> returns the value entry for that parameter. If a I<VALUE> is provided, it will set this value for the given name.
-if no I<NAME>, and no I<VALUE> was provided, B<private> returns a list of all the name-value pair currently set, or a reference to that associative array in scalar context.
+Given a I<NAME>, L</private> returns the value entry for that parameter. If a I<VALUE> is provided, it will set this value for the given name.
+if no I<NAME>, and no I<VALUE> was provided, L</private> returns a list of all the name-value pair currently set, or a reference to that associative array in scalar context.
 
 =head2 subscriber( [ PHONE ] )
 
